==> hqsoft_core-0.0.34.tar.gz: lib/value_base/colors.dart <==
import 'package:flutter/material.dart';

final Color colorPrimary = Color(0xFFE41A23);
final Color colorPrimaryDark = Color(0xFFAF0E13);
final Color colorPrimaryDarkIcon = Color(0xFFAF0E13);

final Color colorPrimaryIsRequired = Color(0xFFD5262B);
final Color colorPrimaryRadio = Color(0xFFD5262B);
final Color colorCart = Colors.redAccent;
final Color colorBackgroundGreyItem = Color(0xAAD3D3D3);
final Color colorBackgroundWhiteItem = Colors.white;
final Color colorColorPrimaryButtonMessDialog = Colors.blue;
final Color colorColorHintButtonMessDialog = Colors.grey;
final Color colorBackground = Colors.grey.shade200;
final Color colorBlue = Colors.blue;
final Color colorSkeletonBoxDecoration = Colors.grey[100];
final Color colorSkeletonShimmer = Colors.grey[100];
final Color colorSkeletonGradient = Colors.grey[100];

final Color colorAccentButton = Colors.white.withOpacity(0.3);
final Color colorPrimaryTextButton = Colors.white;
final Color colorPrimaryButton = Color(0xFFD5262B);

const Color textPrimaryLightColor = Colors.white;
const Color textPrimaryBlack = Colors.black;
const Color textPrimaryGrey = Color(0xFF595959);
const Color textPrimaryGrey1 = Colors.grey;
const Color textPrimaryRed = Colors.red;
const Color colorRed = Color(0xFFfc0101);
const Color colorRed1 = Color(0xFFEE0000);
const Color colorWhite = Color(0xFFFFFFFF);
const Color colorOrange = const Color(0xFFFF682D);
const Color colorMenuLeft = const Color(0xFFEFF8FF);

const Color colorHintText = Color.fromRGBO(164, 164, 168, 1);
const Color colorTextFocus = Color.fromRGBO(13, 12, 34, 1);

==> hqsoft_core-0.0.83.tar.gz: lib/value_base/colors.dart <==
import 'package:flutter/material.dart';

final Color colorPrimary = Color(0xFFE41A23);
final Color colorPrimaryDark = Color(0xFFAF0E13);
final Color colorPrimaryDarkIcon = Color(0xFFAF0E13);

final Color colorPrimaryIsRequired = Color(0xFFD5262B);
final Color colorPrimaryRadio = Color(0xFFD5262B);
final Color colorCart = Colors.redAccent;
final Color colorBackgroundGreyItem = Color(0xAAD3D3D3);
final Color colorBackgroundWhiteItem = Colors.white;
final Color colorColorPrimaryButtonMessDialog = Colors.blue;
final Color colorColorHintButtonMessDialog = Colors.grey;
final Color colorBackground = Colors.grey.shade200;
final Color colorBlue = Colors.blue;
final Color? colorSkeletonBoxDecoration = Colors.grey[100];
final Color? colorSkeletonShimmer = Colors.grey[100];
final Color? colorSkeletonGradient = Colors.grey[100];

final Color colorAccentButton = Colors.white.withOpacity(0.3);
final Color colorPrimaryTextButton = Colors.white;
final Color colorPrimaryButton = Color(0xFFD5262B);

const Color textPrimaryLightColor = Colors.white;
const Color textPrimaryBlack = Colors.black;
const Color textPrimaryGrey = Color(0xFF595959);
const Color textPrimaryGrey1 = Colors.grey;
const Color textPrimaryRed = Colors.red;
const Color colorRed = Color(0xFFfc0101);
const Color colorRed1 = Color(0xFFEE0000);
const Color colorWhite = Color(0xFFFFFFFF);
const Color colorOrange = const Color(0xFFFF682D);
const Color colorMenuLeft = const Color(0xFFEFF8FF);

const Color colorHintText = Color.fromRGBO(164, 164, 168, 1);
const Color colorTextFocus = Color.fromRGBO(13, 12, 34, 1);
